import { useEffect, useRef, useState } from "react";

export function LazyImage({ src, alt, className }: { src: string; alt: string; className?: string; }) {
    const ref = useRef<HTMLImageElement>(null);
    const [loaded, setLoaded] = useState(false);

    useEffect(() => {
        if (ref.current) {
            let toggle = false;
            const observer = new IntersectionObserver((entries) => {
                if (entries.some(x => x.isIntersecting)) {
                    setLoaded(true);
                    toggle = !toggle;
                    ref.current?.animate([{ opacity: 0 }, { opacity: 1 }], { duration: 500, easing: "ease-in-out" });
                    observer.disconnect();
                }
                else {
                    if (toggle) {
                        console.log("fade out");
                        ref.current?.animate([{ opacity: 1 }, { opacity: 0 }], { duration: 500, easing: "ease-in-out" });
                    }
                }
            });
            observer.observe(ref.current);
            return () => {
                observer.disconnect();
            };
        }
    }, []);

    return <img
        ref={ref}
        src={loaded ? src : undefined}
        alt={alt}
        className={className}
        loading="lazy" />;
}
