import { badgeVariants } from "@/components/ui/badge.tsx";
import { Link } from "wouter";
import { cn } from "@/lib/utils.ts";

function getTagKind(tagname: string) {
    if (tagname.match(":") === null) {
        return "default";
    }
    const prefix = tagname.split(":")[0];
    return prefix;
}

function toPrettyTagname(tagname: string): string {
    const kind = getTagKind(tagname);
    const name = tagname.slice(kind.length + 1);

    switch (kind) {
        case "male":
            return `♂ ${name}`;
        case "female":
            return `♀ ${name}`;
        case "artist":
            return `🎨 ${name}`;
        case "group":
            return `🖿 ${name}`;
        case "series":
            return `📚 ${name}`
        case "character":
            return `👤 ${name}`;
        case "default":
            return tagname;
        default:
            return name;
    }
}

export default function TagBadge(props: { tagname: string, className?: string; disabled?: boolean;}) {
    const { tagname } = props;
    const kind = getTagKind(tagname);
    return <li className={
        cn( badgeVariants({ variant: "default"}) ,
            "px-1",
            kind === "male" && "bg-[#2a7bbf] hover:bg-[#3091e7]",
            kind === "female" && "bg-[#c21f58] hover:bg-[#db2d67]",
            kind === "artist" && "bg-[#319795] hover:bg-[#38a89d]",
            kind === "group" && "bg-[#805ad5] hover:bg-[#8b5cd6]",
            kind === "series" && "bg-[#dc8f09] hover:bg-[#e69d17]",
            kind === "character" && "bg-[#52952c] hover:bg-[#6cc24a]",
            kind === "type" && "bg-[#d53f8c] hover:bg-[#e24996]",
            kind === "default" && "bg-[#4a5568] hover:bg-[#718096]",
            props.disabled && "opacity-50",
            props.className,
        )
    }><Link to={props.disabled ? '': `/search?allow_tag=${tagname}`}>{toPrettyTagname(tagname)}</Link></li>;
}