import { Box, Paper, Typography } from "@mui/material";
import { DataGrid, GridColDef } from "@mui/x-data-grid";
import React, { useEffect, useState } from "react";
import { LoadingCircle } from "../component/loading";
import { CommonMenuList, Headline } from "../component/mod";
import { PagePad } from "../component/pagepad";

type TagCount = {
	tag_name: string;
	occurs: number;
};

const tagTableColumn: GridColDef[] = [
	{
		field: "tag_name",
		headerName: "Tag Name",
		width: 200,
	},
	{
		field: "occurs",
		headerName: "Occurs",
		width: 100,
		type: "number",
	},
];

function TagTable() {
	const [data, setData] = useState<TagCount[] | undefined>();
	const [error, setErrorMsg] = useState<string | undefined>(undefined);
	const isLoading = data === undefined;

	useEffect(() => {
		loadData();
	}, []);

	if (isLoading) {
		return <LoadingCircle />;
	}
	if (error !== undefined) {
		return <Typography variant="h3">{error}</Typography>;
	}
	return (
		<Box sx={{ height: "400px", width: "100%" }}>
			<Paper sx={{ height: "100%" }} elevation={2}>
				<DataGrid rows={data} columns={tagTableColumn} getRowId={(t) => t.tag_name}></DataGrid>
			</Paper>
		</Box>
	);

	async function loadData() {
		try {
			const res = await fetch("/api/tags?withCount=true");
			const data = await res.json();
			setData(data);
		} catch (e) {
			setData([]);
			if (e instanceof Error) {
				setErrorMsg(e.message);
			} else {
				console.log(e);
				setErrorMsg("");
			}
		}
	}
}

export const TagsPage = () => {
	const menu = CommonMenuList();
	return (
		<Headline menu={menu}>
			<PagePad>
				<TagTable></TagTable>
			</PagePad>
		</Headline>
	);
};
